@@ -1,33 +1,27 @@
-from sys import exc_info
-
-class Error(Exception):
+class CLIError(Exception):
     """Base class for exceptions in this module."""
     pass
 
-class ConnectionTimeOut(Error):
+class ConnectionTimeOut(CLIError):
     """Exception raised when server closes connection due timeout"""
 
     def __init__(self, message='Server has closed the connection due time out'):
-        self.expression = exc_info()[2]
-        self.message = message  
+        super().__init__(message)
 
-class CommandFailedError(Error):
+class CommandFailedError(CLIError):
     """Exception raised when server occures an error"""
 
     def __init__(self, message="Failed while executing the command"):
-        self.expression = exc_info()[2]
-        self.message = message  
+        super().__init__(message)
     
-class NotValidCGPStringError(Error):
+class NotValidCGPStringError(CLIError):
     """Exception raised when parser can't parse a string"""
 
     def __init__(self, message='Can not parse this string'):
-        self.expression = exc_info()[2]
-        self.message = message
+        super().__init__(message)
     
-class FailedLogin(Error):
+class FailedLogin(CLIError):
     """Exception raised when username or password does not match"""
 
     def __init__(self, message='Wrong username or password'):
-        self.expression = exc_info()[2]
-        self.message = message
\ No newline at end of file
+        super().__init__(message)
\ No newline at end of file
