@@ -2,6 +2,7 @@ import re
 from itertools import chain
 from ipaddress import ip_address
 from datetime import datetime
+import xml.etree.ElementTree as ET
 
 from CGPCLI.Errors import NotValidCGPStringError
 
@@ -59,13 +60,13 @@ def parse_to_python_object(string):
             date, src = match.groups()
             yield datetime.strptime(date, '#T%d-%m-%Y_%H:%M:%S'), src
 
-    xml_regex = re.compile(r"(<.+?>)([;,].*)", re.DOTALL)
+    xml_regex = re.compile(r"(<.+?>.*</.+?>)(.*)", re.DOTALL)
     
     def parse_xml(src):
         match = xml_regex.match(src)
         if match is not None:
             xml, src = match.groups()
-            yield xml, src
+            yield ET.fromstring(xml), src
     
     ip_regex = re.compile(r"#I\[([a-zA-Z0-9.:]*)](?::(\d+))?(.*)", re.DOTALL)
 
@@ -83,7 +84,7 @@ def parse_to_python_object(string):
             sert, src = match.groups()
             yield sert, src
 
-    quoted_regex = re.compile(r"\"(.*?(?<!\\))\"(.*)", re.DOTALL)
+    quoted_regex = re.compile(r"\"(.*?)(?:(?<!\\)\"|\"$|;)(.*)", re.DOTALL)#r"\"(.*?(?<!\\))\"(.*)"     \"(.*?(?:\"\b.+)?)\"(.*)
     unquoted_regex = re.compile(r"([\w.@#-]+)(.*)", re.DOTALL)
 
     def parse_string(src):
@@ -252,4 +253,4 @@ def parse_to_CGP_object(python_object):
     elif python_object is None:
         return "#NULL#" # "null"
         
-    return result
+    return result
\ No newline at end of file
